@@ -3,7 +3,7 @@ import inquirer
 import typer
 from jira import JIRAError
 
-from ttool.jira_utils.utils import CONFIG_FILE, get_config, Config, get_jira_projects
+from ttool.jira_utils.utils import CONFIG_FILE, get_config, Config, get_jira_projects, JiraHostType
 
 YES = 'yes'
 NO = 'no'
@@ -29,15 +29,27 @@ def set_up_jira():
             message="Enter your atlassian server (https://some_server.atlassian.net/)",
             default=default_values.server
         ),
+        inquirer.List(
+            'host_type',
+            message="Enter your atlassian host type",
+            choices=list(JiraHostType.__members__.keys()),
+            default=None
+        ),
     ]
 
-    server = inquirer.prompt(questions)['server']
+    answers = inquirer.prompt(questions)
+    server = answers['server']
     if not server:
         typer.secho("Atlassian server was not entered! run set_up again", fg=typer.colors.RED, err=True)
         raise typer.Exit()
 
+    host_type = answers['host_type']
+    if not server:
+        typer.secho("Atlassian host type was not entered! run set_up again", fg=typer.colors.RED, err=True)
+        raise typer.Exit()
+
     try:
-        projects = get_jira_projects(server)
+        projects = get_jira_projects(server=server, jira_host_type=host_type)
     except JIRAError:
         typer.secho("The given atlassian server is invalid", fg=typer.colors.RED, err=True)
         raise typer.Exit()
@@ -46,7 +58,7 @@ def set_up_jira():
     questions = [
         inquirer.List(
             'project_name',
-            message="Pick your team's project key:",
+            message="Pick your team's project key",
             choices=choices.values(),
             default=choices.get(default_values.project_name)
         ),
@@ -57,7 +69,7 @@ def set_up_jira():
         if choice == answer:
             project_name = key
 
-    config = Config(server=server, project_name=project_name)
+    config = Config(server=server, project_name=project_name, jira_host_type=host_type)
     config.save()
 
 
